#
# spec file for package axel
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?license: %global license %doc}
%{!?make_build: %global make_build make %{?_smp_mflags}}
Name:           axel
Version:        2.17.14
Release:        1.1
Summary:        Lightweight Download Accelerator
License:        GPL-2.0-or-later
URL:            https://github.com/axel-download-accelerator/axel
Source:         https://github.com/axel-download-accelerator/axel/releases/download/v%{version}/%{name}-%{version}.tar.xz
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(openssl)

%description
Axel tries to accelerate HTTP/FTP downloading process by using multiple
connections for one file. It can use multiple mirrors for a download. Axel has
no dependencies and is lightweight, so it might be useful as a wget clone on
byte-critical systems.

%prep
%setup -q

%build
%configure
%make_build

%install
%make_install

%find_lang axel

%files -f axel.lang
%doc ChangeLog NEWS README.md
%license COPYING
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}

%changelog
* Sun Jun 30 2024 jun wang <jgwang@suse.com>
- Update to version 2.17.14
  * Remove inclusion of <stdatomic.h>
  * configure: Fix handling of --with-ssl=yes
  * conn: Fix potential buffer overrun
  * http: Fix filename parsing from Content-Disposition
  * configure: Force C89-compliant return type of signal handlers
  * configure: Update to autoconf 2.72
* Mon Mar 18 2024 Dirk Müller <dmueller@suse.com>
- update to 2.17.13:
  * abuf: Fix realloc usage
  * configure: Fix handling of --with-ssl
  * random: Initialize fd at startup
  * Fixed a wrong translation for Turkish
  * Implemented early redirect loop detection
  * Added LGTM.com support
  * Buildsystem improvements
  * Added wolfSSL support
  * Fixed potential int overflow
  * Simplified configuration support code
  * Early redirect loop detection improvements
  * Fixed speed-limiting sleep delay overflow
  * Removed HTTP encoding of URLs on the CLI, should be pre-
    encoded
* Tue Jan 18 2022 Antoine Belvire <antoine.belvire@opensuse.org>
- Update to 2.17.11:
  * Fixed a deadlock in conn_info
  * Fixed build on FreeBSD (workaround for hidden typedefs)
  * Added SPDX license information
  * Improved reporting of HTTP status codes
  * Source-code simplifications
  * Buildsystem improvements
    + Check intmax_t >= int64_t on Mac OS X
    + Improved output when pkg-config is unavailable
  * Implemented percentage output mode for piping
  * Fixed typos
  * Added Turkish Translation
* Sun Nov 22 2020 Avindra Goolcharan <avindra@opensuse.org>
- update to 2.17.10:
  * Potential NULL pointer dereference
  * Fixed incrementig procedure for delay_time
  * Fixed speed limiting
  * Made stop signal handler portable
  * Build system improvements
  - Now you can specify where OpenSSL is installed
  - Further improved code portability
  * Optimized wildcard search in URLs
  * Added human-readable file size report at the begining of downloads
  * Reworked Request Range support check
  * Added "Accept-Encoding" header to requests
  * Updated the documentation
  * Fixed data type for sizes and offsets on 32-bit systems
  * Fixed duplicated non-default port when using proxy
  * Fixed request range comparison and overflow
  * i8n fixes and updates for Simplified Chinese, Dutch, German,
    Italian, Portuguese, Spanish. Also updates for Indonesian,
    Japanese, Russian.
- CREDITS and AUTHORS files removed from upstream
* Fri Aug 21 2020 Matthias Eliasson <elimat@opensuse.org>
- update to 2.17.9:
  * Fixed insecure mode certificate checking error.
  * Fixed progress bar for large number of connections.
  * Fixed some race conditions with conn_t.
  * Removed limitations on state file name length.
  * Removed limitations on HTTP query length.
  * Fixed a memory leak when deleting the download state file.
  * Added coding style aid and licensing rules to CONTRIBUTING.md.
  * Updated and improved README.md.
  * Cleanup of code & build system.
  * Made the help flag report axel's version number.
  * Updated Chinese translation.
- run spec-cleaner
  * remove rpm groups
* Sun May 31 2020 Andreas Stieger <andreas.stieger@gmx.de>
- update to 2.17.8:
  * CVE-2020-13614: SSL Certificate Hostnames were not verified
    (boo#1172159)
  * Replaced progressbar line clearing with terminal control sequence
  * Fixed parsing of Content-Disposition HTTP header
  * Fixed User-Agent HTTP header never being included
* Sun Mar 29 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 2.17.7:
  - Buildsystem fixes
  - Fixed release date for man-pages on BSD
  - Explicitly close TCP sockets on SSL connections too
  - Fixed HTTP basic auth header generation
  - Changed the default progress report to "alternate output mode"
  - Improved English in README.md
* Thu Oct 24 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 2.17.6:
  - Fixed handling of non-recoverable HTTP errors
  - Cleanup of connection setup code
  - Fixed manpage reproducibility issue
  - Use tracker instead of PTS from Debian
- update to version 2.17.5:
  - Fixed progress indicator misalignment
  - Cleaned up the wget-like progress output code
  - Improved progress output flushing
- update to version 2.17.4:
  - Fixed build with bionic libc (Android)
  - TCP Fast Open support on Linux
  - TCP code cleanup
  - Removed dependency on libm
  - Data types and format strings cleanup
  - String handling cleanup
  - Format string checking GCC attributes added
  - Buildsystem fixes and improvements
  - Updates to the documentation
  - Updated all translations
  - Fixed Footnotes in documentation
  - Fixed a typo in README.md
* Sun Jun  9 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 2.17.3:
  - Builds now use canonical host triplet instead of `uname -s`
  - Fixed build on Darwin / Mac OS X
  - Fixed download loops caused by last byte pointer being off by one
  - Fixed linking issues (i18n and posix threads)
  - Updated build instructions
  - Code cleanup
  - Added autoconf-archive to building instructions
- update to version 2.17.2:
  - Fixed HTTP request-ranges to be zero-based
  - Fixed typo "too may" -> "too many"
  - Replaced malloc + memset calls with calloc
  - Sanitize progress bar buffer len passed to memset
- update to version 2.17.1:
  - Fixed comparison error in axel_divide
  - Make sure maxconns is at least 1
- update to version 2.17:
  - Fixed composition of URLs in redirections
  - Fixed request range calculation
  - Updated all translations
  - Updated build documentation
  - Major code cleanup
  - Cleanup of alternate progress output
  - Removed global string buffers
  - Fixed min and max macros
  - Moved User-Agent header to conf->add_header
  - Use integers for speed ratio and delay calculation
  - Added support for parsing IPv6 literal hostname
  - Fixed filename extraction from URL
  - Fixed request-target message to proxy
  - Handle secure protocol's schema even with SSL disabled
  - Fixed Content-Disposition filename value decoding
  - Strip leading hyphens in extracted filenames
* Thu Mar 21 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- fix broken URL
* Sat Mar 10 2018 sebix+novell.com@sebix.at
- update to version 2.16.1:
  * no noteable changes
* Sun Nov 26 2017 aavindraa@gmail.com
- update to 2.16
  * Buildsystem fixes and improvements
  * Fixed bug that produces empty files with -q/--quiet
  * Fixed build with --disable-nls
  * Fixed formatting of the version/copyright message
  * Header files reorganization
  * Spanish translation
  * Style fixes
  * Updated Portuguese translation
* Sat Nov 11 2017 sebix+novell.com@sebix.at
- added more documentation files and license to package
* Sat Nov 11 2017 aavindraa@gmail.com
- update to 2.15 (see ChangeLog for release notes and all changes
  since 2.4)
- switch to new github url
- run spec-cleaner
- drop all patches
  * axel-fix_buffer_overflow.patch
    + upstreamed in 425dd156b76f2377a3e386324c282bdcdac90a40
  * axel-getaddrinfo.patch
    + upstreamed in cc1142b8de01e182cbaf4cc8a606c80696d8c0b8
  * axel-fix-url-max-length.patch
    + upstreamed in ce40ee76c25a84f386128927fcd0bab4e9751268
  * axel-2.4-configure.patch
    + unneeded
* Wed Apr 12 2017 sebix+novell.com@sebix.at
- run spec-cleaner
- add axel-fix-url-max-length.patch to accept longer URLs
* Thu Dec 22 2011 andreas.stieger@gmx.de
- Update License to GPL-2.0+
- add axel-2.4-configure.patch to make configure script accept and
  ignore --disable-dependency-tracking
* Tue Oct 12 2010 pascal.bleser@opensuse.org
- copied from home:bitshuffler to network:utilities
- revamped .spec file
- added patch to fix buffer overflow
- added patch to use getaddrinfo instead of gethostbyname
* Fri Jul  3 2009 bitshuffler #suse@irc.freenode.org
- Initial RPM
